==> apache-cxf-3.2.7-src.zip: apache-cxf-3.2.7-src/systests/jaxws/src/test/java/org/apache/cxf/systest/swa/Server.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.systest.swa;

import javax.xml.ws.Endpoint;

import org.apache.cxf.jaxws.EndpointImpl;
import org.apache.cxf.testutil.common.AbstractBusTestServerBase;
import org.apache.cxf.testutil.common.TestUtil;

public class Server extends AbstractBusTestServerBase {

    protected void run() {
        String port = TestUtil.getPortNumber(Server.class);

        Object implementor = new SwAServiceImpl();
        String address = "http://localhost:" + port + "/swa";
        EndpointImpl ep;
        try {
            ep = (EndpointImpl) Endpoint.create(new SwANoMimeServiceImpl());
            ep.setWsdlLocation("classpath:wsdl/swa-mime-nomime.wsdl");
            ep.publish(address + "-nomime");


            ep = (EndpointImpl) Endpoint.create(implementor);
            ep.setWsdlLocation("classpath:wsdl/swa-mime.wsdl");
            ep.publish(address);
        } catch (Exception e) {
            e.printStackTrace();
            Thread.currentThread().interrupt();
        }
    }

    public static void main(String args[]) {
        try {
            Server s = new Server();
            s.start();
        } catch (Exception ex) {
            ex.printStackTrace();
            System.exit(-1);
        } finally {
            System.out.println("done!");
        }
    }
}

==> apache-cxf-3.5.10-src.zip: apache-cxf-3.5.10-src/systests/jaxws/src/test/java/org/apache/cxf/systest/swa/Server.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.systest.swa;

import javax.xml.ws.Endpoint;

import org.apache.cxf.jaxws.EndpointImpl;
import org.apache.cxf.testutil.common.AbstractBusTestServerBase;
import org.apache.cxf.testutil.common.TestUtil;

public class Server extends AbstractBusTestServerBase {

    protected void run() {
        String port = TestUtil.getPortNumber(Server.class);

        Object implementor = new SwAServiceImpl();
        String address = "http://localhost:" + port + "/swa";
        EndpointImpl ep;
        try {
            ep = (EndpointImpl) Endpoint.create(new SwANoMimeServiceImpl());
            ep.setWsdlLocation("classpath:wsdl/swa-mime-nomime.wsdl");
            ep.publish(address + "-nomime");


            ep = (EndpointImpl) Endpoint.create(implementor);
            ep.setWsdlLocation("classpath:wsdl/swa-mime.wsdl");
            ep.publish(address);
        } catch (Exception e) {
            e.printStackTrace();
            Thread.currentThread().interrupt();
        }
    }

    public static void main(String[] args) {
        try {
            Server s = new Server();
            s.start();
        } catch (Exception ex) {
            ex.printStackTrace();
            System.exit(-1);
        } finally {
            System.out.println("done!");
        }
    }
}
